@@ -2,7 +2,7 @@
 /**
  *
  * @author Petri Asikainen
- * @version $Id: lib.php,v 1.61.2.15 2005/11/07 00:38:23 martinlanghoff Exp $
+ * @version $Id: lib.php,v 1.77.2.3 2006/06/29 07:03:38 skodak Exp $
  * @license http://www.gnu.org/copyleft/gpl.html GNU Public License
  * @package moodleauth
  
@@ -127,16 +127,26 @@ function auth_get_userinfo($username){
             $ldapval = NULL;
             foreach ($values as $value) {
                 if(is_array($user_entry[0][strtolower($value)])) {
-                    $newval = addslashes(stripslashes(utf8_decode($user_entry[0][strtolower($value)][0])));
+                    if (!empty($CFG->unicodedb)) {
+                        $newval = addslashes(stripslashes($user_entry[0][strtolower($value)][0]));
+                    } else {
+                        $newval = addslashes(stripslashes(utf8_decode($user_entry[0][strtolower($value)][0])));
+                    }
                 }
                 else {
-                    $newval = addslashes(stripslashes(utf8_decode($user_entry[0][strtolower($value)])));
+                    if (!empty($CFG->unicodedb)) {
+                        $newval = addslashes(stripslashes($user_entry[0][strtolower($value)]));
+                    } else {
+                        $newval = addslashes(stripslashes(utf8_decode($user_entry[0][strtolower($value)])));
+                    }
                 }
                 if (!empty($newval)) { // favour ldap entries that are set
                     $ldapval = $newval;
                 } 
             }
-            $result[$key] = $ldapval;
+            if (!is_null($ldapval)) {
+                $result[$key] = $ldapval;
+            }
         }
     }
 
@@ -206,7 +216,11 @@ function auth_user_create ($userobject,$plainpass) {
         }
         foreach ($values as $value) {
             if(!empty($userobject->$key) ){
-                $newuser[$value]=utf8_encode($userobject->$key);
+                if (!empty($CFG->unicodedb)) {
+                    $newuser[$value]= $userobject->$key;
+                } else {
+                    $newuser[$value]=utf8_encode($userobject->$key);
+                }
             }
         }
     }
@@ -826,7 +840,7 @@ function auth_user_update($olduser, $newuser) {
     if ($user_info_result){
 
         $user_entry = auth_ldap_get_entries($ldapconnection, $user_info_result);
-        if (count($user_entry)) {
+        if (count($user_entry) > 1) {
             trigger_error("ldap: Strange! More than one user record found in ldap. Only using the first one.");
         }
         $user_entry = $user_entry[0];
@@ -1063,7 +1077,7 @@ function auth_ldap_getdefaults(){
                         'rfc2307' => 'member',
                         'rfc2307bis' => 'member',
                         'samba' => 'member',
-                        'ad' => 'memberOf', 
+                        'ad' => 'member', 
                         'default' => 'member'
                         );
     $default['ldap_memberattribute_isdn'] = array(
@@ -1071,7 +1085,7 @@ function auth_ldap_getdefaults(){
                         'rfc2307' => '0',
                         'rfc2307bis' => '1',
                         'samba' => '0', //is this right?
-                        'ad' => '0', //is this right?
+                        'ad' => '1',
                         'default' => '0'
                         );
     $default['ldap_expireattr'] = array (
@@ -1246,7 +1260,8 @@ function auth_ldap_isgroupmember ($username='', $groupdns='') {
         }
         //echo "Checking group $group for member $username\n";
         $search = @ldap_read($ldapconnection, $group,  '('.$CFG->ldap_memberattribute.'='.$username.')', array($CFG->ldap_memberattribute));
-        if (ldap_count_entries($ldapconnection, $search)) {$info = auth_ldap_get_entries($ldapconnection, $search);
+
+        if (!empty($search) AND ldap_count_entries($ldapconnection, $search)) {$info = auth_ldap_get_entries($ldapconnection, $search);
         
             if (count($info) > 0 ) {
                 // user is member of group
