@@ -1,4 +1,4 @@
-<?php // $Id: block_glossary_random.php,v 1.15.2.1 2005/07/23 00:52:47 defacer Exp $
+<?php // $Id: block_glossary_random.php,v 1.16.8.1 2006/05/29 08:15:23 moodler Exp $
 
 define('BGR_RANDOMLY',     '0');
 define('BGR_LASTMODIFIED', '1');
@@ -13,8 +13,8 @@ class block_glossary_random extends block_base {
     }
 
     function specialization() {
-        global $CFG;
-        $this->course = get_record('course', 'id', $this->instance->pageid);
+        global $CFG, $COURSE;
+        $this->course = $COURSE;
 
         // load userdefined title and make sure it's never empty
         if (empty($this->config->title)) {
